/*
 * Copyright (C) 2001 Red Hat, Inc.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* Just a dummy file for gettext, containing messages emmitted by various
 * commonly-used PAM modules. */
gchar* ud_ok_text = N_("OK");
gchar* ud_exit_text = N_("Exit");
gchar* ud_cancel_text = N_("Cancel");
gchar* ud_fallback_text = N_("Run Unprivileged");
gchar* label0 = N_("(current) UNIX password: ");
gchar* label1 = N_("New UNIX password: ");
gchar* label2 = N_("Retype new UNIX password: ");
gchar* label3 = N_("BAD PASSWORD: it's WAY too short");
gchar* label4 = N_("BAD PASSWORD: it is too short");
gchar* label5 = N_("Password unchanged");
gchar* label6 = N_("Sorry, passwords do not match");
gchar* label7 = N_("Launch system-wide configuration tools without a password.");
gchar* ud_login_text = N_("login: ");
gchar* ud_password_text = N_("Password: ");
